/* 
   ----------------             pipetree.pov (WIP 1)            ------------------------
   ----------------                05.June 2003                 ------------------------
   ----------------       copyright by Norbert W. Kern          ------------------------
   ----------------      norbert-werner.kern@t-online.de        ------------------------ 
*/


// The scene is based on macros of Gilles Tran and resembles his image 'Family'.
// It uses a modified version of Maketree.pov; don't miss www.oyonale.com for the original macros and artwork of Gilles Tran!



#version 3.5;

#declare file_done = 0;   // 0 to generate pipe files in a first pass, set to 1 afterwords to reduce parsing time

#declare PHOT      = 0;  // photons 0=out; 1=save photons; 2=load photons
#declare Save_Rad  = 1;  // 1=save rad; 2=load rad data; 0=no rad storing
#declare RAD       = 1;  // radiosity quality settings 0=out; 1=acceptable; 5=good
                
global_settings {
        #declare a_g = 1;
        assumed_gamma a_g
        max_trace_level 5
        noise_generator 2
        #if (PHOT > 0)
                photons {
                        spacing  0.05
                        autostop 0
                        jitter 1
                        #if (PHOT = 1)
                                save_file "pov.ph"
                        #else
                                load_file "pov.ph"
                        #end                        
                }
        #end  
        #if(RAD > 0)
                radiosity {
                        #if (Save_Rad  = 1)
                                pretrace_start   0.08
                                pretrace_end     0.005
                                error_bound      0.5
                                low_error_factor 0.5
                        #else
                                pretrace_start   1
                                pretrace_end     1
                                error_bound      0.5
                        #end 
                        count                    160                                
                        recursion_limit          1
                        nearest_count            6  
                        gray_threshold           0  
                        minimum_reuse            0.015 
                        brightness               1.4      
                        adc_bailout              0.005
                        normal on
                        media off
                        #if (Save_Rad = 1)
                                save_file "pov.rad"
                        #else
                                #if (Save_Rad = 2)
                                        load_file "pov.rad" 
                                        always_sample off
                                #end
                        #end                          
                }
        #end
}        

#declare diff = 1;

#if (RAD > 0)
        #default {finish {ambient 0 diffuse diff*0.7}}
#end

#macro G(Color,g)
        rgb <pow(Color.x,g),pow(Color.y,g),pow(Color.z,g)>
#end 

#declare Gamma = 2.2/a_g;

sky_sphere {
        pigment {
                gradient y 
                color_map {
                        [0.0000 color G(<212,221,239>/255,Gamma)]
                        [0.1029 color G(<219,229,244>/255,Gamma)]
                        [0.1512 color G(<233,241,250>/255,Gamma)]
                        [0.1949 color G(<223,239,252>/255,Gamma)]
                        [0.2444 color G(<201,227,252>/255,Gamma)]
                        [0.2921 color G(<180,213,250>/255,Gamma)]
                        [0.3732 color G(<144,180,239>/255,Gamma)]
                        [0.4255 color G(<137,172,235>/255,Gamma)]
                        [0.7067 color G(< 97,126,198>/255,Gamma)]
                        [0.7740 color G(< 92,119,190>/255,Gamma)]
                        [0.8275 color G(< 88,114,185>/255,Gamma)]
                        [0.8850 color G(< 85,111,180>/255,Gamma)]                        
                        [0.9425 color G(< 82,107,175>/255,Gamma)]                        
                        [1.0000 color G(< 79,103,170>/255,Gamma)]
                }
        }
}

#include "colors.inc"
#include "textures.inc"
#include "metals.inc" 
#include "transforms.inc"

camera {
        location <15,-15,-38>
        direction 1.5*z 
        right 4/3*x 
        look_at <5,-8.5,0>
        angle 65
}

//-----------------------------------------
// Textures
//-----------------------------------------      

#declare colWall = color rgb <0.85,0.95,0.94>*0.3;
#declare colPipe = color rgb <0.95,0.9,0.8>*0.2;
#declare txtPipe1 =
texture {
        pigment {
                agate
                color_map {
                        [0   color colPipe]
                        [0.3 color colWall]
                        [1   color colWall]
                }
        } 
        normal {agate 0.1}
        finish {diffuse 0.2 ambient 0}
        scale 0.5
}

#declare txtSkin =
texture {
        pigment {color rgb <1,0.7,0.1>} 
        finish {metallic brilliance 6 ambient 0 specular 0.8 roughness 0.05}
}

#declare rusted_metal =
texture {
        pigment {color rgb 0.7} 
        finish {metallic brilliance 6 ambient 0 specular 0.8 roughness 0.05}
}


//-----------------------------------------
// Pipes
//-----------------------------------------

#declare nDeco = 7;
#declare Deco = array[nDeco]
#include "pipedeco.inc"

#declare box_hole = <0,0,0>;  // no hole = decorations everywhere
#declare dPipe = 0; // 3D pipes (dPipe=1 = 2D pipes on the x-y plane)

#include "madpipe.inc"

//-----------------------wall--------------------------------------------------------------------------------------------

#declare container1 = <-65,-35,40>;
#declare container2 = <40,40,60>; 
#declare container = <abs(container1.x-container2.x),abs(container1.y-container2.y),abs(container1.z-container2.z)>/2;
#declare cont_schwerpunkt4 = <container1.x+container2.x,container1.y+container2.y,container1.z+container2.z>/2;
#if (file_done = 0)
        #declare nPipe = 2000;
        #declare rPipe = 0.5;
        #declare lPipe = 8;  
        #declare Pipe_4 = object {MadPipe(rPipe,lPipe,nPipe,dPipe,container,box_hole,2,27643,true,"wpipe_4.inc")}
#end
object {#include "WPipe_4.inc" texture{rusted_metal} translate cont_schwerpunkt4}   

#declare container1 = <-20,-35,40>;
#declare container2 = <20,40,50>; 
#declare container = <abs(container1.x-container2.x),abs(container1.y-container2.y),abs(container1.z-container2.z)>/2;
#declare cont_schwerpunkt4a = <container1.x+container2.x,container1.y+container2.y,container1.z+container2.z>/2;
#if (file_done = 0)
        #declare nPipe = 1400;
        #declare rPipe = 0.15;
        #declare lPipe = 3;  
        #declare Pipe_4a = object {MadPipe(rPipe,lPipe,nPipe,dPipe,container,box_hole,2,27643,true,"wpipe_4a.inc")}
#end
object {#include "WPipe_4a.inc" texture{rusted_metal} translate cont_schwerpunkt4a}

//-----------------------ground--------------------------------------------------------------------------------------------

#declare container1 = <-30,-35,-50>;
#declare container2 = <30,-25,60>; 
#declare container = <abs(container1.x-container2.x),abs(container1.y-container2.y),abs(container1.z-container2.z)>/2;
#declare cont_schwerpunkt5 = <container1.x+container2.x,container1.y+container2.y,container1.z+container2.z>/2;
#if (file_done = 0)
        #declare nPipe = 1500;
        #declare rPipe = 0.25;
        #declare lPipe = 5;  
        #declare Pipe_4 = object {MadPipe(rPipe,lPipe,nPipe,dPipe,container,box_hole,2,27643,true,"wpipe_5.inc")}
#end
object {#include "WPipe_5.inc" texture{rusted_metal} translate cont_schwerpunkt5}

//-----------------------left--------------------------------------------------------------------------------------------

#declare container1 = <-25,-30,10>;
#declare container2 = <-20,40,50>; 
#declare container = <abs(container1.x-container2.x),abs(container1.y-container2.y),abs(container1.z-container2.z)>/2;
#declare cont_schwerpunkt6 = <container1.x+container2.x,container1.y+container2.y,container1.z+container2.z>/2;
#if (file_done = 0)
        #declare nPipe = 1000;
        #declare rPipe = 0.15;
        #declare lPipe = 2.5;  
        #declare Pipe_4 = object {MadPipe(rPipe,lPipe,nPipe,dPipe,container,box_hole,2,27643,true,"wpipe_6.inc")}
#end
object {#include "WPipe_6.inc" texture{rusted_metal} translate cont_schwerpunkt6}

#declare container1=<-25,0,-50>;
#declare container2=<-20,40,10>;  
#declare container = <abs(container1.x-container2.x),abs(container1.y-container2.y),abs(container1.z-container2.z)>/2;
#declare cont_schwerpunkt7 = <container1.x+container2.x,container1.y+container2.y,container1.z+container2.z>/2;
#if (file_done = 0)  
        #declare Pipe_4 = object {MadPipe(rPipe,lPipe,nPipe,dPipe,container,box_hole,2,27643,true,"wpipe_7.inc")}
#end
object {#include "WPipe_7.inc" texture{rusted_metal} translate cont_schwerpunkt7}

#declare container1 = <-25,-30,10>;
#declare container2 = <-20,40,40>; 
#declare container = <abs(container1.x-container2.x),abs(container1.y-container2.y),abs(container1.z-container2.z)>/2;
#declare cont_schwerpunkt6 = <container1.x+container2.x,container1.y+container2.y,container1.z+container2.z>/2;
#if (file_done = 0)
        #declare nPipe = 900;
        #declare rPipe = 0.3;
        #declare lPipe = 2.5;  
        #declare Pipe_4 = object {MadPipe(rPipe,lPipe,nPipe,dPipe,container,box_hole,2,27643,true,"wpipe_6a.inc")}
#end
object {#include "WPipe_6a.inc" texture{rusted_metal} translate cont_schwerpunkt6}

#declare container1=<-25,0,-50>;
#declare container2=<-20,40,10>;  
#declare container = <abs(container1.x-container2.x),abs(container1.y-container2.y),abs(container1.z-container2.z)>/2;
#declare cont_schwerpunkt7 = <container1.x+container2.x,container1.y+container2.y,container1.z+container2.z>/2;
#if (file_done = 0)  
        #declare Pipe_4 = object {MadPipe(rPipe,lPipe,nPipe,dPipe,container,box_hole,2,27643,true,"wpipe_7a.inc")}
#end
object {#include "WPipe_7a.inc" texture{rusted_metal} translate cont_schwerpunkt7}

//-----------------------right--------------------------------------------------------------------------------------------

#declare container1=<25,-30,10>;
#declare container2=<20,40,50>; 
#declare container = <abs(container1.x-container2.x),abs(container1.y-container2.y),abs(container1.z-container2.z)>/2;
#declare cont_schwerpunkt8 = <container1.x+container2.x,container1.y+container2.y,container1.z+container2.z>/2;
#if (file_done = 0)
        #declare nPipe = 1000;
        #declare rPipe = 0.15;
        #declare lPipe = 2.5;    
        #declare Pipe_4 = object {MadPipe(rPipe,lPipe,nPipe,dPipe,container,box_hole,2,27643,true,"wpipe_8.inc")}
#end
object {#include "WPipe_8.inc" texture{rusted_metal} translate cont_schwerpunkt8}

#declare container1=<25,0,-50>;
#declare container2=<20,40,10>;  
#declare container = <abs(container1.x-container2.x),abs(container1.y-container2.y),abs(container1.z-container2.z)>/2;
#declare cont_schwerpunkt9 = <container1.x+container2.x,container1.y+container2.y,container1.z+container2.z>/2;
#if (file_done = 0)  
        #declare Pipe_4 = object {MadPipe(rPipe,lPipe,nPipe,dPipe,container,box_hole,2,27643,true,"wpipe_9.inc")}
#end
object {#include "WPipe_9.inc" texture{rusted_metal} translate cont_schwerpunkt9}

#declare container1=<25,-30,10>;
#declare container2=<20,40,40>; 
#declare container = <abs(container1.x-container2.x),abs(container1.y-container2.y),abs(container1.z-container2.z)>/2;
#declare cont_schwerpunkt8 = <container1.x+container2.x,container1.y+container2.y,container1.z+container2.z>/2;
#if (file_done = 0)
        #declare nPipe = 900;
        #declare rPipe = 0.3;
        #declare lPipe = 2.5;  
        #declare Pipe_4 = object {MadPipe(rPipe,lPipe,nPipe,dPipe,container,box_hole,2,27643,true,"wpipe_8a.inc")}
#end
object {#include "WPipe_8a.inc" texture{rusted_metal} translate cont_schwerpunkt8}

#declare container1=<25,0,-50>;
#declare container2=<20,40,10>;  
#declare container = <abs(container1.x-container2.x),abs(container1.y-container2.y),abs(container1.z-container2.z)>/2;
#declare cont_schwerpunkt9 = <container1.x+container2.x,container1.y+container2.y,container1.z+container2.z>/2;
#if (file_done = 0)  
        #declare Pipe_4 = object {MadPipe(rPipe,lPipe,nPipe,dPipe,container,box_hole,2,27643,true,"wpipe_9a.inc")}
#end
object {#include "WPipe_9a.inc" texture{rusted_metal} translate cont_schwerpunkt9}


//-----------------------------------------
// Environment
//-----------------------------------------

union {
        box {<-100,-60, 75>,< 100, 81, 66>}  //wand
        box {<-100,-60,-55>,< 100, 81,-50>}  //rueckwand
        box {<-101,-60, 75>,<-100, 81,-55>}  //links
        box {< 100,-60, 75>,< 101, 81,-55>}  //rechts
        box {<-101,-61, 75>,< 101,-60,-55>}  //unten
        box {<-101, 51,-10>,< 101, 82,-55>}  //oben hinten
        box {<-101, 71, 40>,< 101, 82, 66>}  //oben hinten
        texture {txtPipe1}
}

//-----------------------------------------
// Sun
//-----------------------------------------  

light_source {<50,1000,0> color rgb <1,0.834,0.566>*8}

//-----------------------------------------
// Tree
//-----------------------------------------
  
#include "Pipetree2.inc"


//-----------------------------------------
// Atmosphere
//-----------------------------------------

box {
        <-50,-25,-40>,<50,50,50>
        material {
                texture {pigment {color rgbf 1}}
                interior {
                        media {
                                confidence 0.0001
                                variance 1
                                ratio 0.1
                                scattering {3, rgbt <0.0007,0.00085,0.001,0.5>}
                        }
                }
        }
        hollow
}